==> ckeditor_4.4.4+dfsg1.orig.tar.xz: ckeditor-dev-4.4.4/plugins/forms/lang/uk.js <==
﻿/*
Copyright (c) 2003-2014, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'uk', {
	button: {
		title: 'Властивості кнопки',
		text: 'Значення',
		type: 'Тип',
		typeBtn: 'Кнопка (button)',
		typeSbm: 'Надіслати (submit)',
		typeRst: 'Очистити (reset)'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Властивості галочки',
		radioTitle: 'Властивості кнопки вибору',
		value: 'Значення',
		selected: 'Обрана'
	},
	form: {
		title: 'Властивості форми',
		menu: 'Властивості форми',
		action: 'Дія',
		method: 'Метод',
		encoding: 'Кодування'
	},
	hidden: {
		title: 'Властивості прихованого поля',
		name: 'Ім\'я',
		value: 'Значення'
	},
	select: {
		title: 'Властивості списку',
		selectInfo: 'Інфо',
		opAvail: 'Доступні варіанти',
		value: 'Значення',
		size: 'Кількість',
		lines: 'видимих позицій у списку',
		chkMulti: 'Список з мультивибором',
		opText: 'Текст',
		opValue: 'Значення',
		btnAdd: 'Добавити',
		btnModify: 'Змінити',
		btnUp: 'Вгору',
		btnDown: 'Вниз',
		btnSetValue: 'Встановити як обране значення',
		btnDelete: 'Видалити'
	},
	textarea: {
		title: 'Властивості текстової області',
		cols: 'Стовбці',
		rows: 'Рядки'
	},
	textfield: {
		title: 'Властивості текстового поля',
		name: 'Ім\'я',
		value: 'Значення',
		charWidth: 'Ширина',
		maxChars: 'Макс. к-ть символів',
		type: 'Тип',
		typeText: 'Текст',
		typePass: 'Пароль',
		typeEmail: 'Пошта',
		typeSearch: 'Пошук',
		typeTel: 'Мобільний',
		typeUrl: 'URL'
	}
} );

==> ckeditor_4.5.6+dfsg.orig.tar.xz: ckeditor-dev-4.5.6/plugins/forms/lang/uk.js <==
﻿/*
Copyright (c) 2003-2015, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'uk', {
	button: {
		title: 'Властивості кнопки',
		text: 'Значення',
		type: 'Тип',
		typeBtn: 'Кнопка (button)',
		typeSbm: 'Надіслати (submit)',
		typeRst: 'Очистити (reset)'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Властивості галочки',
		radioTitle: 'Властивості кнопки вибору',
		value: 'Значення',
		selected: 'Обрана',
		required: 'Обов’язкове поле'
	},
	form: {
		title: 'Властивості форми',
		menu: 'Властивості форми',
		action: 'Дія',
		method: 'Метод',
		encoding: 'Кодування'
	},
	hidden: {
		title: 'Властивості прихованого поля',
		name: 'Ім\'я',
		value: 'Значення'
	},
	select: {
		title: 'Властивості списку',
		selectInfo: 'Інфо',
		opAvail: 'Доступні варіанти',
		value: 'Значення',
		size: 'Кількість',
		lines: 'видимих позицій у списку',
		chkMulti: 'Список з мультивибором',
		required: 'Обов’язкове поле',
		opText: 'Текст',
		opValue: 'Значення',
		btnAdd: 'Добавити',
		btnModify: 'Змінити',
		btnUp: 'Вгору',
		btnDown: 'Вниз',
		btnSetValue: 'Встановити як обране значення',
		btnDelete: 'Видалити'
	},
	textarea: {
		title: 'Властивості текстової області',
		cols: 'Стовбці',
		rows: 'Рядки'
	},
	textfield: {
		title: 'Властивості текстового поля',
		name: 'Ім\'я',
		value: 'Значення',
		charWidth: 'Ширина',
		maxChars: 'Макс. к-ть символів',
		required: 'Обов’язкове поле',
		type: 'Тип',
		typeText: 'Текст',
		typePass: 'Пароль',
		typeEmail: 'Пошта',
		typeSearch: 'Пошук',
		typeTel: 'Мобільний',
		typeUrl: 'URL'
	}
} );
